<?php
function pngToIco($inputPngPath, $outputIcoPath, $sizes) {
    if (!extension_loaded('gd')) {
        throw new Exception('GD Library ist nicht verfügbar');
    }

    $sourceImage = imagecreatefrompng($inputPngPath);
    if (!$sourceImage) {
        throw new Exception('Fehler beim Laden des PNG-Bildes');
    }

    $icoFile = fopen($outputIcoPath, 'wb');
    if (!$icoFile) {
        throw new Exception('Fehler beim Erstellen der ICO-Datei');
    }

    fwrite($icoFile, pack('vvv', 0, 1, count($sizes)));

    $imageData = '';
    $offset = 6 + (16 * count($sizes));

    foreach ($sizes as $size) {
        $resizedImage = imagecreatetruecolor($size, $size);
        imagesavealpha($resizedImage, true);
        imagealphablending($resizedImage, false);
        imagecopyresampled($resizedImage, $sourceImage, 0, 0, 0, 0, $size, $size, imagesx($sourceImage), imagesy($sourceImage));

        ob_start();
        imagepng($resizedImage);
        $pngData = ob_get_clean();
        imagedestroy($resizedImage);

        fwrite($icoFile, pack('CCCCvvVV', $size, $size, 0, 0, 1, 32, strlen($pngData), $offset));

        $imageData .= $pngData;
        $offset += strlen($pngData);
    }

    fwrite($icoFile, $imageData);
    fclose($icoFile);
    imagedestroy($sourceImage);
}

if ($_SERVER['REQUEST_METHOD'] === 'POST' && isset($_FILES['pngFiles']) && isset($_POST['sizes'])) {
    $sizes = array_map('intval', $_POST['sizes']); // Die ausgewählten Größen holen
    $uploadDir = 'uploads/';
    if (!is_dir($uploadDir)) {
        mkdir($uploadDir, 0777, true);
    }

    $thumbnails = [];
    foreach ($_FILES['pngFiles']['tmp_name'] as $index => $tempPath) {
        $originalName = pathinfo($_FILES['pngFiles']['name'][$index], PATHINFO_FILENAME);
        $icoFilePath = $uploadDir . $originalName . '.ico';

        if (move_uploaded_file($tempPath, $uploadDir . $_FILES['pngFiles']['name'][$index])) {
            try {
                pngToIco($uploadDir . $_FILES['pngFiles']['name'][$index], $icoFilePath, $sizes);
                unlink($uploadDir . $_FILES['pngFiles']['name'][$index]);
                $thumbnails[] = $icoFilePath;
            } catch (Exception $e) {
                echo "Fehler bei " . $_FILES['pngFiles']['name'][$index] . ": " . $e->getMessage();
            }
        } else {
            echo "Fehler beim Hochladen der Datei: " . $_FILES['pngFiles']['name'][$index];
        }
    }

    // Archiv-Verzeichnis mit Zeitstempel erstellen
    $timestamp = date('Y-m-d_H-i-s');
    $archiveDir = "Archiv/$timestamp/";
    if (!is_dir($archiveDir)) {
        mkdir($archiveDir, 0777, true);
    }

    // Konvertierte ICO-Dateien in das Archiv-Verzeichnis verschieben
    foreach ($thumbnails as $file) {
        copy($file, $archiveDir . basename($file));
        unlink($file);  // Datei nach dem Kopieren aus dem Upload-Ordner löschen
    }

    // Leere index.html in das Archiv-Verzeichnis speichern
    file_put_contents($archiveDir . 'index.php', '<?php header("Location: ../../index.php"); ?>');

    // Weiterleitung zur Anzeige der Ergebnisse
    header("Location: index.php?archive=" . urlencode($archiveDir) . "&thumbnails=" . urlencode(json_encode(array_map(fn($file) => $archiveDir . basename($file), $thumbnails))));
    exit;
}
?>
